@@ -1,6 +1,7 @@
 import pandas as pd
 import numpy as np
 import pandas_ta as ta
+import math
 
 
 def stochastic_oscillator(dataframe, k=14, d=3, smooth_k=3, mamode='sma'):
@@ -1007,3 +1008,76 @@ def calculate_slope(dataframe, source):
         print(f"Exception in Calculating {source} Slope : {e}")
         pass
 
+
+def tam_variant(dataframe, src="close", ma_type="EMA",  length=21, off_sig=10, off_alma=0.90):
+    """ Function to calculate TA Matrix """
+    try:
+        print(f"Calculating Trend Alpha Matrix Variant")
+        src = dataframe[src]
+
+        # 1. Basic moving averages
+        v1 = ta.sma(src, length)
+        v2 = ta.ema(src, length)
+        v3 = 2 * v2 - ta.ema(v2, length)
+        v4 = 3 * (v2 - ta.ema(v2, length)) + ta.ema(ta.ema(v2, length), length)
+        v5 = ta.wma(src, length)
+        v6 = ta.vwma(src, length)
+
+        v7 = src.copy()
+        for i in range(1, len(src)):
+            if pd.isna(v7[i - 1]):
+                v7[i] = src[:i + 1].mean()
+            else:
+                v7[i] = (v7[i - 1] * (length - 1) + src.iloc[i]) / length
+
+        v8 = ta.wma(2 * ta.wma(src, length/2)) - ta.wma(src, length), int(round(math.sqrt(length)))
+        v9 = ta.linreg(src, length, offset=off_sig)
+        v10 = ta.alma(close=src, length=length, offset=off_alma, sigma=off_sig)
+        v11 = ta.sma(v1, length)
+
+        # 7. Super Smoother (SSMA)
+        a1 = math.exp(-1.414 * math.pi / length)
+        b1 = 2 * a1 * math.cos(1.414 * math.pi / length)
+        c2 = b1
+        c3 = -a1 * a1
+        c1 = 1 - c2 - c3
+
+        v12 = np.zeros(len(src))
+        for i in range(len(src)):
+            if i == 0:
+                v12[i] = src.iloc[i]
+            elif i == 1:
+                v12[i] = c1 * (src.iloc[i] + src.iloc[i - 1]) / 2 + c2 * v12[i - 1]
+            else:
+                v12[i] = c1 * (src.iloc[i] + src.iloc[i - 1]) / 2 + c2 * v12[i - 1] + c3 * v12[i - 2]
+
+        v12 = pd.Series(v12, index=src.index)
+
+        # Return appropriate MA type
+        if ma_type == "EMA":
+            return v2
+        elif ma_type == "DEMA":
+            return v3
+        elif ma_type == "TEMA":
+            return v4
+        elif ma_type == "WMA":
+            return v5
+        elif ma_type == "VWMA":
+            return v6
+        elif ma_type == "SMMA":
+            return v7
+        elif ma_type == "HullMA":
+            return v8
+        elif ma_type == "LSMA":
+            return v9
+        elif ma_type == "ALMA":
+            return v10
+        elif ma_type == "TMA":
+            return v11
+        elif ma_type == "SSMA":
+            return v12
+        else:
+            return v1
+    except Exception as e:
+        print(f"Exception in TA Matrix Variant : {e}")
+        pass
