@@ -31,6 +31,26 @@ def fetch_orders_list(redis_cursor, request_id):
         pass
 
 
+def fetch_orders_mgdb(db_cursor, request_id, mode="vt"):
+    """ Function to Fetch Orders list for Request ID """
+    try:
+        print()
+        if mode == "vt":
+            orders_col = "vt_orders"
+        elif mode == "lt":
+            orders_col = "lt_orders"
+        else:
+            orders_col = "bt_orders"
+        orders_list = db_cursor[orders_col].find({"request_id": ObjectId(request_id)})
+        if orders_list:
+            return list(orders_list)
+        else:
+            return None
+    except Exception as e:
+        print(f"Exception in fetching orders list : {e}")
+        pass
+
+
 def fetch_last_order(redis_cursor, request_id):
     """Function to fetch last order from redis database"""
     try:
@@ -67,6 +87,8 @@ def check_open_orders(orders_list):
                     quantity_dict[trade_symbol]["order_timestamp"] = datetime.datetime.strptime(str(order["order_timestamp"]), '%Y-%m-%d %H:%M:%S')
 
                     # Adding Good to Have Fields
+                    quantity_dict[trade_symbol]["position_type"] = order.get("position_type", "")
+                    quantity_dict[trade_symbol]["spot_price"] = order.get("spot_price")
                     quantity_dict[trade_symbol]["strike_price"] = order.get("strike_price", "")
                     quantity_dict[trade_symbol]["option_type"] = order.get("option_type", "")
                     quantity_dict[trade_symbol]["bnf_price"] = order.get("bnf_price")
@@ -111,7 +133,8 @@ def convert_to_trades(orders_list, market_type, order_exit_levels, mode, broker)
                 trade_dict["lot_size"] = order["lot_size"]
                 trade_dict["position_type"] = order.get("position_type", "LONG")
                 trade_dict["bnf_price"] = order.get("bnf_price", "")
-                trade_dict["bar_color"] = order["bar_color"]
+                trade_dict["spot_price"] = order.get("spot_price", "")
+                trade_dict["bar_color"] = order.get("bar_color", "")
                 trade_dict["entry_time"] = order["order_timestamp"]
                 trade_dict["entry_price"] = order["trigger_price"]
                 trade_dict["quantity"] = order["quantity"]
