@@ -879,6 +879,9 @@ def apply_indicators(dataframe, indicators_dict):
                 volma_df = TA.sma(close=dataframe["volume"], length=indicators_dict["VOLMA"]["length"])
             dataframe["volma"] = round(volma_df, 2).fillna(0).values
 
+        if "TAM" in indicators_dict:
+            dataframe["tam_variant"] = tam_variant(dataframe=dataframe, ma_type=indicators_dict["TAM"]["ma_type"], src=indicators_dict["TAM"]["src"],
+                                                   length=indicators_dict["TAM"]["length"], off_sig=indicators_dict["TAM"]["off_sig"], off_alma=indicators_dict["TAM"]["off_alma"])
         return dataframe
 
     except Exception as e:
